import { Or, IsNever, NonNegativeInteger, IsEqual, GreaterThan, GreaterThanOrEqual, IntRange } from 'type-fest';

type RandomInteger<From extends number, To extends number> = Or<IsNever<NonNegativeInteger<From>>, IsNever<NonNegativeInteger<To>>> extends true ? number : IsEqual<From, To> extends true ? From : GreaterThan<From, To> extends true ? never : GreaterThanOrEqual<To, 1000> extends true ? number : IntRange<From, To> | To;
/**
 * Generate a random integer between `from` and `to` (inclusive).
 *
 * @param from - The minimum value.
 * @param to - The maximum value.
 * @returns The random integer.
 * @signature
 *   R.randomInt(from, to)
 * @example
 *   R.randomInt(1, 10) // => 5
 *   R.randomInt(1.5, 2.6) // => 2
 * @dataFirst
 * @category Number
 */
declare function randomInteger<From extends number, To extends number>(from: From, to: To): RandomInteger<From, To>;

export { randomInteger };
